import setuptools

setuptools.setup(
    name='medusa-workflow-bot',
    version='0.0.0',
    author='Mario Corchero',
    description='Reserved',
    packages=[],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 2",
    ]
    )
